@@ -1,3 +1,19 @@
+#  Copyright 2023 Synnax Labs, Inc.
+#
+#  Use of this software is governed by the Business Source License included in the file
+#  licenses/BSL.txt.
+#
+#  As of the Change Date specified in that file, in accordance with the Business Source
+#  License, use of this software will be governed by the Apache License, Version 2.0,
+#  included in the file licenses/APL.txt.
+#
+#  Use of this software is governed by the Business Source License included in the file
+#  licenses/BSL.txt.
+#
+#  As of the Change Date specified in that file, in accordance with the Business Source
+#  License, use of this software will be governed by the Apache License, Version 2.0,
+#  included in the file licenses/APL.txt.
+
 import fnmatch
 
 from ..flow import Context
@@ -7,14 +23,17 @@ def prompt_group_channel_names(
     ctx: Context,
     channels: list[str],
 ) -> dict[str, list[str]] | None:
-    ctx.console.info("""
+    ctx.console.info(
+        """
     You can enter 'all' for all channels or a comma-separated list of:
     1) Names (e.g. 'channel1, channel2, channel3')
     2) Channel indices (e.g. '1, 2, 3')
     3) A pattern to match (e.g. 'channel*, sensor*')
     4) A combination of the above (e.g. '1, 2, channel3, my_dog*')
-    """)
-    res = ctx.console.ask("channels")
+    """
+    )
+    res = ctx.console.ask("channels", required=True)
+    assert res is not None
     return group_channel_names(ctx, channels, res.split(","))
 
 
